/*
 * Copyright (c) 2007 Konopa-Jelen-Majer
 * All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 *
 * - Redistributions of source code must retain the above copyright
 *   notice, this list of conditions and the following disclaimer.
 * - Redistributions in binary form must reproduce the above copyright
 *   notice, this list of conditions and the following disclaimer in the
 *   documentation and/or other materials provided with the distribution.
 * - The name of the author may not be used to endorse or promote products
 *   derived from this software without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE AUTHOR ``AS IS'' AND ANY EXPRESS OR
 * IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES
 * OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED.
 * IN NO EVENT SHALL THE AUTHOR BE LIABLE FOR ANY DIRECT, INDIRECT,
 * INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT
 * NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE,
 * DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY
 * THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
 * (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF
 * THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */

/** @addtogroup FileSystemTask
 * @{
 */ 

/**
 * @file	connect.h
 * @brief	 Functions for connecting to some services, which is needed for FS. 
 */

#include <ipc/ipc.h>
#include <ipc/services.h>
#include "../fs/fs.h"

/**
 * Includes common aspects for connecting to some services
 */ 
int common_connection(int *phone, int service, int attempts)
{
	
	int i;

	if (service <= 0 || attempts <= 0)
		return FALSE;
			
	for (i = 1; i <= attempts; i++) {
		*phone = ipc_connect_me_to(PHONE_NS, service, 0);
		
		if (*phone > 0)
			return TRUE;
		
		usleep(10000);
	}
	
	if (*phone >= 0)
		return TRUE;

	return FALSE;
}

/**
 * Connects to SERVICE_CONSOLE
 */ 
int connect_to_con(int *phone, int attempts)
{
	
	if (common_connection(phone, SERVICE_CONSOLE, attempts))
		return TRUE;

	return FALSE;	
}

/**
 * Connects to SERVICE_RD
 */
int connect_to_rd(int *phone, int attempts)
{
		
	if (common_connection(phone, SERVICE_RD, attempts))
		return TRUE;

	return FALSE;	
}

/**
 * Connects to SERVICE_FS
 */
int connect_to_fs(int *phone, int attempts)
{
		
	if (common_connection(phone, SERVICE_FS, attempts))
		return TRUE;

	return FALSE;	
}

/**
 *}
 */
   
